#!/usr/bin/perl -w

package KurssiParser;

use HTML::Parser;

@ISA = qw(HTML::Parser);

sub new() {
  my $self = HTML::Parser->new;
  bless $self;
  $self->{curtag} = "";
  $self->{text} = "";
  $self->{luentoja} = 0;
  $self->{harjoituksia} = 0;
  $self->{ajat} = "";
  $self->{ov} = 0;
  $self->{esitiedot} = [];
  return $self;
}

sub start( $$$$$ ) {
  my ($self, $tag, $attr, $attrSeq, $origText) = @_;
  if (exists $self->{on}->{$tag}) {
    my $func = $self->{on}->{$tag};
    &$func;
    delete $self->{on}->{$tag};
  }
  if (exists $self->{on}->{""}) {
    my $func = $self->{on}->{""};
    &$func;
    delete $self->{on}->{""};
  }
  if ($tag eq "table" ) {
    $self->{table} = [];
    $self->{tablex} = 0;
    $self->{tabley} = 0;
  }
  $self->{curtag} = $tag;
  $self->{data}->{$tag} = "";
  $self->{text} = "";
  $self->{on} = {};
}

sub _trim( $ ) {
  my $s = $_[0];
  $s =~ s/^ *//g;
  $s =~ s/ *$//g;
  return $s;
}

sub text( $$ ) {
  my ($self, $text) = @_;
  if ($text =~ /Luentoja ([0-9]*)/) {
    $self->{luentoja} = $1;
  }
  if ($text =~ /arjoituksia ([0-9]*)/) {
    $self->{harjoituksia} = $1;
  }
  $self->{text} .= $text;
}

sub end( $$$ ) {
  my ($self, $tag, $origText) = @_;
  if (exists $self->{on}->{$tag}) {
    my $func = $self->{on}->{$tag};
    &$func;
    delete $self->{on}->{$tag};
  }
  if (exists $self->{on}->{""}) {
    my $func = $self->{on}->{""};
    &$func;
    delete $self->{on}->{""};
  }
  if ($tag eq "th" or
      $tag eq "td") {
    $self->{table}->[$self->{tabley}]->[$self->{tablex}] = $self->{text};
    $self->{tablex}++;
  }
  if ($tag eq "tr") {
    $self->{tabley}++;
    $self->{tablex} = 0;
  }
  if ($tag eq "h4") {
    if ($self->{text} =~ /Luentopaikka/) {
      $self->{on}->{""} = sub ( $ ) {
	my ($self) = @_;
	$self->{text} =~ s/[\n\r]/ /gs;
	$self->{ajat} = _trim($self->{text});
      };
    }
  }
  if ($tag eq "h1") {
    if ($self->{text} =~ /^ *([0-9]{2,}) *(.*?), *([-0-9,]*) ov$/) {
      $self->{kurssi} = _trim($1);
      $self->{kurssiNimi} = $2;
      $self->{ov} = $3;
    }
  }
  if ($tag eq "h4") {
    if ($self->{text} =~ /esitiedot/) {
      $self->{on}->{""} = sub ( $ ) {
	my ($self) = @_;
	$self->{text} =~ s/[\n\r]/ /gs;
	while ($self->{text} =~ /\G[^0-9]*([0-9]{3,})/g) {
	  push @{$self->{esitiedot}}, $1;
	}
      };
    }
  }
  $self->{text} = "";
}


